@@ -74,6 +74,15 @@ class Service(object):
         order = order.create(generic_values, payload)
         return self.send_order('B03', order)
 
+    def get_contract(self, generic_values, payload):
+        """
+        Sends B03 order to meter
+        :return: Success or fail
+        """
+        order = Order('B04')
+        order = order.create(generic_values, payload)
+        return self.send_order('B04', order)
+
     def get_meter_modification(self, generic_values, payload):
         """
         Sends B09 order to meter
